# Alma SRU

This module is intended for searching the library software system Alma
for single or multiple records. The search for single records must be
done with a unique ID (e. g. Barcode) and will return exactly one
xml.etree.ElementTree Element. The search for multiple records will
return an iterable containing such Elements.

When querying for multiple records, keep in mind that Ex Libris limits
the retrieval of records to 10k.

To use this module you will need to know at least the following
information (there is a submodule with the necessary info for ONB):
* The subdomain of the Alma installation
* The institution code of the institution you want to query
* Which format you want returned

See also [Ex Libris' documentation on SRU](https://developers.exlibrisgroup.com/alma/integrations/SRU/) and
[general information on SRU by the LOC](http://www.loc.gov/standards/sru/).

## Usage

For general Alma-queries from *almasru* instantiate RecordRetriever
with the necessary information:
```
from catalogue.sru import almasru
nzalma = almasru.RecordRetriever('obv-at-oenb', '43ACC_NETWORK', 'marcxml')
```

If you want to query the Austrian National Library's catalogue,
you can also use *onbsru*:

```
from catalogue.sru import onbsru
onbalma = onbsru.OnbRecordRetriever()
```

You can either query by unique ID or by a more general query.
If you query by unique ID and more than one record is returned,
you will get a Not Unique-Exception.

There are the following unique IDs implemented as methods
of the *RecordRetriever()*:
* barcode - Barcode of a specific item
* by\_marc\_009 - other system number of a bibliographic record,
 e. g. AC-number (UID used in the Austrian Library Network)
* mms\_id - Ex Libris Alma's internal ID of a bibliographic record

### By Unique ID

There are shorthands for AC-number, MMS-ID or Barcode:
```
onbalma.by_marc_009('AC13425588')
onbalma.by_barcode('+Z171377605')
onbalma.by_mms_id('990000063950503338')
```

They all are based on a more general method for retrieving records by unique ID:
```
onbalma.get_unique('alma.local_control_field_009=AC13425588')
```

### By Any Query
For documentation on what can be queried here, look at the out of the box
[search indexes](https://knowledge.exlibrisgroup.com/Alma/Product_Documentation/010Alma_Online_Help_(English)/040Resource_Management/040Metadata_Management/180Search_Indexes/050MARC_21_Search_Indexes) of Alma and at the [explain operation](https://obv-at-oenb.alma.exlibrisgroup.com/view/sru/43ACC_ONB?version=1.2&operation=explain) of SRU.
```
query = "alma.date_of_publication=1848 and alma.country_of_publication=XA-AAAT"
onbalma.get_multiple(query)
```

# Author
Gabriele Höfler
